@@ -1,5 +1,7 @@
-from .cbir import *
 from .dtr import *
 from .plt_dtr import *
+from .cbir import *
+from .ml import *
+from .utils import *
 
-__version__ = '0.1.1'
\ No newline at end of file
+__version__ = '0.2.1'
